#delimit cr
set more off
cap log close
discard 
clear


set logtype text
log using graphs_accepted, replace

set mem 700m
set matsize 800

/***************************************************************************************************
                                This program reproduces the figures: A1, A2, A3
*****************************************************************************************************/


/******************************************************************************************
 FIGURE A1: IMPORT PENETRATION FROM CHINA AND OTHER COUNTRIES IN ITALY
******************************************************************************************/

use schott

keep anno nace2 impchina imptot x vship

sort nace2 anno

save temp1, replace

clear

use trade

keep anno nace2 imp_tot exp_tot imp_china prod

sort nace2 anno

merge nace2 anno using temp1

tab _merge
drop _merge

erase temp1.dta

drop if anno<1994
drop if anno>2006

drop if nace2==16
drop if nace2==37
drop if nace2==23
drop if nace2==30

sort anno 

collapse (sum) imp_tot exp_tot imp_china prod impchina imptot x vship, by(anno)


gen impenit_istat=(imp_tot)/(prod-exp_tot+imp_tot)
gen impenit_other_istat=(imp_tot-imp_china)/(prod-exp_tot+imp_tot)
gen impenit_china_istat=(imp_china)/(prod-exp_tot+imp_tot)

gen impenus_china_schott=impchina/(vship-x+imptot)
gen impenus_other_schott=(imptot-impchina)/(vship-x+imptot)
gen impenus_schott=imptot/(vship-x+imptot)

* base 1994=100

replace impenit_china_istat=impenit_china_istat/0.0038637*100
replace impenit_other_istat=impenit_other_istat/0.2077782*100


twoway (line impenit_china_istat anno) (line impenit_other_istat anno), ytitle("") xtitle("") legend(label(1 "China") label(2 "Other countries")) xlabel(1994(3) 2005) saving(impen_total, replace)


/******************************************************************************************
FIGURE A2: KERNEL DENSITY OF INVIND PRICES: RAW DATA, NET OF YEAR DUMMIES, NET OF YEAR AND SECTOR DUMMIES
********************************************************************************************/
clear all

clear

use data_BFS_china

keep if anno>1995
keep if j2==1 & outlier==0

gen dataset=0
replace dataset=1 if absmpenit_china_istat!=. & absmpenit_other_istat!=. & absmpenus_china_costante!=. &  absmpenus_other_costante!=. & deltaconcr!=. & ddemimp!=. &  deltacfs2!=. & deltacostlab2!=. & deltaop_tfp!=. & deltasize!=. & v220a!=.

keep if dataset==1

iis v2

reg v220a yd*, robust
predict v220a_1, resid

reg v220a sector* yd* ,  robust
predict v220a_2, resid


kdensity v220a, nograph gen(x1 f1)
kdensity v220a_1, nograph gen(f2) at(x1)
kdensity v220a_2, nograph gen(f3) at(x1)

line f1 f2 f3 x1, sort ytitle("") legend(label(1 "Raw data") label(2 "Net of year effects") label(3 "Net of year and sector effects"))  xtitle("") title("Price change distribution, all years") note("Source: SIM") clpattern(solid shortdash dash) saving(kernel, replace)


/*******************************************************************************
FIGURE 3 - SKEWENESS OF DISTRIBUTIONS 
*******************************************************************************/
 
clear

use data_BFS_china

sort nace2

merge nace2 using dummysect
tab _merge
drop _merge

gen dataset=0
replace dataset=1 if absmpenit_china_istat!=. & absmpenit_other_istat!=. & absmpenus_china_costante!=. &  absmpenus_other_costante!=. & deltaconcr!=. & ddemimp!=. &  deltacfs2!=. & deltacostlab2!=. & deltaop_tfp!=. & deltasize!=. & v220a!=.

/***************************
interactions with dummy for low skill sectors
***************************/

foreach j in lowkl lowhk lowpnp lowqua  {

gen absmpenit_china_`j'=absmpenit_china_istat*`j'
gen absmpenit_other_`j'=absmpenit_other_istat*`j'
gen absmpenus_china_`j'=absmpenus_china_costante*`j'
gen absmpenus_other_`j'=absmpenus_other_costante*`j'

}


gen absmpenit_china_tfp=absmpenit_china_istat*lagop_tfp
gen absmpenit_other_tfp=absmpenit_other_istat*lagop_tfp
gen absmpenus_china_tfp=absmpenus_china_costante*lagop_tfp
gen absmpenus_other_tfp=absmpenus_other_costante*lagop_tfp


/**************************
interactions with dummy for low skill sector and tfp (lag of log tfp)
****************************/

foreach j in lowkl lowhk lowpnp lowqua  {

gen absmpenit_china_tfp_`j'=absmpenit_china_istat*lagop_tfp*`j'
gen absmpenit_other_tfp_`j'=absmpenit_other_istat*lagop_tfp*`j'
gen absmpenus_china_tfp_`j'=absmpenus_china_costante*lagop_tfp*`j'
gen absmpenus_other_tfp_`j'=absmpenus_other_costante*lagop_tfp*`j'

gen tfp_`j'=lagop_tfp*`j'

}
 
 
*** create groups year-sector 
sort nace2 anno
egen setan=group(nace2 anno)

*** set first year dummy to zero to avoid collinearity
replace yd5=0 if yd5==1


*** select years and data as in the main regression of the paper
keep if anno>1995 
keep if dataset==1 & j2==1 & outlier==0

*** check that results are as in the paper
ivreg2 v220a (absmpenit_china_istat absmpenit_china_lowhk absmpenit_china_tfp absmpenit_china_tfp_lowhk absmpenit_other_istat= absmpenus_china_costante absmpenus_china_lowhk absmpenus_china_tfp absmpenus_china_tfp_lowhk absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_lowhk  yd* sector* if j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)

*** predict first stage
reg absmpenit_china_lowhk absmpenus_china_costante absmpenus_china_lowhk absmpenus_china_tfp absmpenus_china_tfp_lowhk absmpenus_other_costante deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_lowhk  yd* sector* if j2==1 & outlier==0, robust  cluster(setan)
predict china_lohk,xb

reg absmpenit_china_tfp_lowhk absmpenus_china_costante absmpenus_china_lowhk absmpenus_china_tfp absmpenus_china_tfp_lowhk absmpenus_other_costante deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_lowhk  yd* sector* if j2==1 & outlier==0, robust  cluster(setan)
predict china_lohk_tfp,xb


g dsh=-16.557*china_lohk+6.063*china_lohk_tfp

sort nace2 anno
by nace2 anno: egen d50_tfp=pctile(lagop_tfp) if lowhk==1, p(50)
gen dlow=0
replace dlow=1 if lagop_tfp<d50_tfp & lowhk==1


summ dsh if lowhk==1,det

summ dsh if lowhk==1 & dlow==1,det

summ dsh if lowhk==1 & dlow==0,det


rename dsh deltaprice_all

g deltaprice_lowskill=deltaprice_all if lowhk==1

g deltaprice_lowskill_lowtfp=deltaprice_all if lowhk==1 & dlow==1


**** this is figure 3
skewplot deltaprice_all deltaprice_lowskill deltaprice_lowskill_lowtfp
graph export skew_all.png
