clear
clear matrix
set mem 500m
set matsize 800
#delimit cr
set more off
cap log close
discard 
clear

set logtype text
log using table_reg, replace

/********************************************************
UPLOAD DATA
Sources: Invind + Cads + sectoral measures from Table A2
*********************************************************/

use data_BFS_china

/*********************************************************************************************************
GENERATE INTERACTION VARS FOR REGRESSIONS WITH FIRM AND SECTOR HETEROGENIETY (TABLE 7)
**********************************************************************************************************/

* interactions between import penetration measures and sectoral dummies (below median value)

foreach j in lowkl lowhk lowpnp lowqua {

gen absmpenit_china_`j'=absmpenit_china_istat*`j'
gen absmpenit_other_`j'=absmpenit_other_istat*`j'
gen absmpenus_china_`j'=absmpenus_china_costante*`j'
gen absmpenus_other_`j'=absmpenus_other_costante*`j'

}

* interactions between import penetration measures and firms' TFP level

gen absmpenit_china_tfp=absmpenit_china_istat*lagop_tfp
gen absmpenit_other_tfp=absmpenit_other_istat*lagop_tfp
gen absmpenus_china_tfp=absmpenus_china_costante*lagop_tfp
gen absmpenus_other_tfp=absmpenus_other_costante*lagop_tfp

* interactions between import penetration measures, sectoral dummies (below median value) and firms' TFP level;
* & interaction between tfp and sectoral measures

foreach j in lowkl lowhk lowpnp lowqua  {

gen absmpenit_china_tfp_`j'=absmpenit_china_istat*lagop_tfp*`j'
gen absmpenit_other_tfp_`j'=absmpenit_other_istat*lagop_tfp*`j'
gen absmpenus_china_tfp_`j'=absmpenus_china_costante*lagop_tfp*`j'
gen absmpenus_other_tfp_`j'=absmpenus_other_costante*lagop_tfp*`j'

gen tfp_`j'=lagop_tfp*`j'

}

/************************************************************
LABELING (MAIN) VARS
*************************************************************/

label variable absmpenit_china_istat  "Dimpen_china"
label variable absmpenit_other_istat  "Dimpen_other"

label variable deltaconcr "Ddomcomp"
label variable ddemimp "Ddemand"
label variable deltasize "Dsize"
label variable deltacfs2 "Dinputcosts"
label variable deltacostlab2 "Dwage"
label variable deltaop_tfp "Dtfp"


/**************************************************
minor adjustments before regressions: i) create sector*year dummies to be used in clustering; ii) force reference year to be the first one; 
iii) drop data before 1995
****************************************************/

sort nace2 anno
egen setan=group(nace2 anno)

replace yd5=0 if yd5==1

keep if anno>1995

* run IV base regression to generate variable (samplx) with sample observations
ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp yd* sector* if  j2==1 & outlier==0, first robust   fwl(yd* sector*) cluster(setan)
g samplx=e(sample)


******************************************************************************************************
************************BASE REGRESSION AND ROBUSTNESS************************************************
******************************************************************************************************


/***************************************************
TABLE 2: BASELINE REGRESSION

column 1: OLS - cluster sector&year
column 2: IV - cluster sector&year, no other controls
column 3: IV - cluster sector&year, all controls
column 4: first stage for import penetration china correspondent to column 3
column 5: first stage for import penetration other (than china) countries correspondent to column 3
***************************************************/

areg v220a absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp yd* sector* if  j2==1 & outlier==0, a(dig2) robust   cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp using tab_base, replace tex title("Baseline regression")  ctitle (OLS) nonotes addnote(Standard errors (in parenthesis) are robust and clustered by sector and year. All regressions include year fixed effects and sector fixed effects. *** p<0.01, ** p<0.05, * p<0.1) bdec(3) rdec(3) label 

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) yd* sector* if samplx==1 & j2==1 & outlier==0, first robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat using tab_base, append tex ctitle(IV) bdec(3) rdec(3) label 

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp yd* sector* if  j2==1 & outlier==0, first robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp using tab_base, append tex ctitle(IV) bdec(3) rdec(3) label 

areg absmpenit_china_istat absmpenus_china_costante absmpenus_other_costante deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp yd* sector* if  j2==1 & outlier==0, a(dig2) robust    cluster(setan)
outreg2 absmpenus_china_costante absmpenus_other_costante deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp using tab_base, append tex ctitle(First stage: China) bdec(3) rdec(3) label 

areg absmpenit_other_istat absmpenus_china_costante absmpenus_other_costante deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp yd* sector* if  j2==1 & outlier==0, a(dig2) robust    cluster(setan)
outreg2 absmpenus_china_costante absmpenus_other_costante deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp using tab_base, append tex ctitle(First stage: others) bdec(3) rdec(3) label 

/***************************************************
TABLE 3: ROBUSTNESS I (always IV specification)

column 1: control for world imports
column 2: control for firm exit
column 3: exclude cells with less than 20 obs
column 4: firm fixed effects and cluster(firm)
***************************************************/

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp deltawt yd* sector* if  j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp deltawt using tab_robu_1, replace tex title("Robustness I")  ctitle (World imports) nonotes addnote(Standard errors (in parenthesis) are robust and clustered by sector and year (in column 2 they are clustered by firm). All regressions include year fixed effects and sector fixed effects. *** p<0.01, ** p<0.05, * p<0.1) bdec(3) rdec(3) label 

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp exit yd* sector* if  j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp exit using tab_robu_1, append tex  ctitle (Firms' exit) nonotes  bdec(3) rdec(3) label 

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp  yd* sector*  if numero>20 & j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp  using tab_robu_1, append tex ctitle (No cells with < 20 obs) bdec(3) rdec(3) label 

iis v2

xtivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp yd* if  j2==1 & outlier==0 & samplx==1, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp using tab_robu_1, append ctitle(firm FE and cluster) tex bdec(3) rdec(3) label 

/***************************************************
TABLE 4: ROBUSTNESS II (always IV specification)

column 1: only firms with export share <=30%
column 2: weighted by share of domestic sales
column 3: including export share
***************************************************/

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp  yd* sector* if lagexpshare<0.3 &  j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp  using tab_robu_2, replace tex title("Robustness II")  ctitle (only firms with export share<=30%) nonotes addnote(Standard errors (in parenthesis) are robust and clustered by sector and year. All regressions include year fixed effects and sector fixed effects. *** p<0.01, ** p<0.05, * p<0.1) bdec(3) rdec(3) label 

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp  yd* sector* [aw=minusexpshare] if j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp  using tab_robu_2, append tex ctitle (weighted by share of domestic sales)  bdec(3) rdec(3) label

ivreg2 v220a (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagexpshare yd* sector*  if j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagexpshare using tab_robu_2, append tex ctitle (including export share)  bdec(3) rdec(3) label

******************************************************************************************************
************************THE MECHANISMS****************************************************************
******************************************************************************************************


/*******************************************************************************************
TABLE 5: MECHANISMS I

IV estimates with firm fixed effects and cleter by firm

column 1: rate of change of wage
column 2: rate of change of intermediate input costs
column 3: rate of change of TFP
column 4: rate of change of K/L
column 5: change of white collar share
*******************************************************************************************/

iis v2

xtivreg2 dep_deltacostlab2 (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_1, replace  tex title("The mechanisms I")  ctitle (delta wage %) nonotes addnote(Standard errors (in parenthesis) are robust and clustered by firm. All regressions include year, firm and sector fixed effects. *** p<0.01, ** p<0.05, * p<0.1)   bdec(3) rdec(3) label 

xtivreg2 dep_deltacfs2 (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_1, append  tex ctitle (delta input costs %) bdec(3) rdec(3) label 

xtivreg2 dep_deltaop_tfp (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_1, append  tex bdec(3) ctitle (delta TFP %) rdec(3) label 

xtivreg2 dep_deltacapl (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_1, append  tex bdec(3) ctitle (delta KL %) rdec(3) label 

xtivreg2 dep_deltashwhi (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_1, append  tex ctitle (delta share of white collar) bdec(3) rdec(3) label 


/*******************************************************************************************
TABLE 6: MECHANISMS II

IV estimates with firm fixed effects and cleter by firm

column 1: rate of change of employment
column 2: rate of change of sales
column 3: rate of change  markup
column 4: change of gross operating profits/value added
column 5: change of ROA
*********************************************************************************************/

iis v2

xtivreg2 dep_deltasize (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_2, replace  tex title("The mechanisms II")   ctitle (delta size %) bdec(3) rdec(3) label 

xtivreg2 dep_deltasales (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_2, append  tex ctitle (delta sales %) bdec(3) rdec(3) label 

xtivreg2 dep_deltamkup4 (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_2, append  tex ctitle (delta markup %) bdec(3) rdec(3) label 

xtivreg2 dep_molva (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_2, append  tex ctitle (delta GOP/VA) bdec(3) rdec(3) label 

xtivreg2 dep_roa (absmpenit_china_istat absmpenit_other_istat= absmpenus_china_costante absmpenus_other_costante) deltaconcr ddemimp  yd* if  samplx==1 & j2==1 & outlier==0, ffirst fe  cluster(v2)
outreg2 absmpenit_china_istat absmpenit_other_istat deltaconcr ddemimp  using tab_mech_2, append  tex ctitle (delta ROA) bdec(3) rdec(3) label 


******************************************************************************************************
************************SECTOR AND FIRM HETEROGENEITY*************************************************
******************************************************************************************************


ivreg2 v220a (absmpenit_china_istat absmpenit_china_tfp absmpenit_china_lowkl absmpenit_china_tfp_lowkl absmpenit_other_istat= absmpenus_china_costante absmpenus_china_lowkl absmpenus_china_tfp absmpenus_china_tfp_lowkl absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_lowkl  yd* sector* if j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_china_tfp absmpenit_china_lowkl absmpenit_china_tfp_lowkl absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_lowkl using tab_het, replace tex bdec(3) rdec(3) label

foreach j in lowhk lowpnp lowqua  {

ivreg2 v220a (absmpenit_china_istat absmpenit_china_tfp absmpenit_china_`j' absmpenit_china_tfp_`j' absmpenit_other_istat= absmpenus_china_costante absmpenus_china_`j' absmpenus_china_tfp absmpenus_china_tfp_`j' absmpenus_other_costante) deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_`j'  yd* sector* if j2==1 & outlier==0, ffirst robust   fwl(yd* sector*) cluster(setan)
outreg2 absmpenit_china_istat absmpenit_china_tfp absmpenit_china_`j' absmpenit_china_tfp_`j' absmpenit_other_istat deltaconcr ddemimp deltasize deltacfs2 deltacostlab2 deltaop_tfp lagop_tfp tfp_`j' using tab_het, append tex bdec(3) rdec(3) label

}

